//Created by Amin Rahmani, Ph.D., P.E. - August 12, 2017
//Copyright © 2018 Amin Rahmani. All rights reserved.

//==========================================================================================================================
//                                '****   Notes  ****
// This ".hpp" file declares variables and classes
// The analysis is performed based on CPT data which must be in Imperial units : depth (ft), cone resistance and sleeve friction in (tsf) and water pressure in (psi). The data must start from line 1 (no header).
// The code is developed for pile groups I_A,B and II_A,B.
//===========================================================================================================================

#ifndef GeoCapac_B_G_1982_hpp
#define GeoCapac_B_G_1982_hpp

#include <stdio.h>
#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>
#include <fstream>

using namespace std;

class B_G_1982 {
    
private:
    //default member variables
    int numDataPoint;
    double a_corr;
    double qca1, qca, Ica, kc, alpha, fp;
    int count ;
    double sum;
    int count_f;
    double sum_f;
    double sum_Ic;
    double Qp_ult;
    //double FoS_end;
    double fs_ult;
    //double FoS_skin;
    
    vector <double> depth;
    vector <double> q_c;
    vector <double> f_s;
    vector <double> u_water;
    vector <double> q_t;
    vector <double> gamma_t;
    vector <double> TotStress;
    vector <double> insitu_hydr;
    vector <double> insitu_EffStress;
    vector <double> n_pow;
    vector <double> CN;
    vector <double> Qn;
    vector <double> Fn;
    vector <double> Ic;
    vector <double> skin_fric;
    
    //User defined member variables
    double GWdepth;
    double columnDiam;
    double columnDepth;
    double zeroFricDepth;
    string inputcptData;
    double FoS_end;
    double FoS_skin;
    string groupID_end;
    string groupID_skin;
    
public:
    //Default constructor
    B_G_1982 ();
    
    //Destructor
    ~B_G_1982 ();
    
    //Main Functions
		//reads CPT file
		void fileReader (string);
		// input values ground water depth, column outside diameter, column depth, zero friction depth, FoS for end bearing, FoS for skin friction, Group ID for end bearing, Group ID for skin friction
		void getValues (double, double, double, double, double, double, string, string);
		//calculates Ic
		void calc_Ic ();
		//calculates geotech capacity
		void calcGeoCap ();
    
};

#endif /* GeoCapac_B_G_1982_hpp */
